croston — croston 0.1.2.1 documentation

# croston

croston model for intermittent time series

`croston.croston.` `fit_croston`(input_endog, forecast_length, croston_variant='original')
  Parameters

    - input_endog – numpy array of intermittent demand time series

    - forecast_length – forecast horizon

    - croston_variant – croston model type

  Returns

    dictionary of model parameters, in-sample forecast, and out-of-sample forecast

`croston.croston.` `_croston`(input_series, input_series_length, croston_variant, w, h, epsilon)

`croston.croston.` `_croston_opt`(input_series, input_series_length, croston_variant, epsilon, w=None, nop=1)

`croston.croston.` `_croston_cost`(p0, input_series, input_series_length, croston_variant, epsilon)